==> 0.2.8.tar.gz: ios/Classes/MzanalyticsMybmwPlugin.m <==
#import "MzanalyticsMybmwPlugin.h"
#import <MZAnalytics_MYBMW_1.0.3_SDK/MLTSiteSDK.h>
#import <MZAnalytics_MYBMW_1.0.3_SDK/MLT_ConfigModel.h>
@implementation MzanalyticsMybmwPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"mzanalytics_mybmw"
            binaryMessenger:[registrar messenger]];
  MzanalyticsMybmwPlugin* instance = [[MzanalyticsMybmwPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    @try {
        
   
   if ([@"appid" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
      [MLTSiteManager sharedInstanceWithAppId:call.arguments[@"appid"]  channel:@"app store"];
     
         
     }else if ([@"trackPageView" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
        
         [[MLTSiteManager  shareInstance] trackPageView:call.arguments[@"dt"]  appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else   if ([@"trackEvent" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
         
      [[MLTSiteManager  shareInstance] trackEvent:call.arguments[@"ec"] eventAction:call.arguments[@"ea"] eventTag:call.arguments[@"el"] eventPrice:call.arguments[@"ev"] appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else  if ([@"trackSiteCustomEvent" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         [[MLTSiteManager  shareInstance] trackSiteCustomEvent:call.arguments[@"CustomEvent"]  appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else  if ([@"trackPulse" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
         
      [[MLTSiteManager  shareInstance] trackPulse];
         
     } else  if ([@"getCid" isEqualToString:call.method]) {
        
            
         result([MLTSiteManager getCid]);
            
        } else  if ([@"setEnableLog" isEqualToString:call.method]) {
            result([NSNumber numberWithBool:YES]);

            [MLTSiteManager setEnableLog:call.arguments[@"Enable"]];
               
           }  else  if ([@"handleOpenURL" isEqualToString:call.method]) {
                  result([NSNumber numberWithBool:YES]);
                     
                     
                  [MLTSiteManager  handleOpenURL:call.arguments[@"url"]];
                     
                 }  else  if ([@"setCd" isEqualToString:call.method]) {
                     result([NSNumber numberWithBool:YES]);
                        
                        
                     [MLTSiteManager setCd:call.arguments[@"cd_key"] forValue:call.arguments[@"cd_value"]];
                        
                    }  else  if ([@"setCm" isEqualToString:call.method]) {
                        result([NSNumber numberWithBool:YES]);
                           
                           
                        [MLTSiteManager setCm:call.arguments[@"cm_key"] forValue:call.arguments[@"cm_value"]];
                           
                       }  else  if ([@"deleteCd" isEqualToString:call.method]) {
                           result([NSNumber numberWithBool:YES]);
                              
                              
                           [MLTSiteManager  deleteCdForKey:call.arguments[@"cd_key"]];
                              
                          }  else  if ([@"deleteCm" isEqualToString:call.method]) {
                              result([NSNumber numberWithBool:YES]);
                                 
                                 
                              [MLTSiteManager  deleteCmForKey:call.arguments[@"cm_key"]];
                                 
                             }  else  if ([@"getCdAndCm" isEqualToString:call.method]) {
                                 result([MLT_ConfigModel shareInstance].dmDict);
                                    
                                    
                             
                                    
                                } else  if ([@"isAutoTrackpage" isEqualToString:call.method]) {
                                
                                    BOOL isAutoTrackpage =[[MLT_ConfigModel shareInstance] isAutoTrackpage];
                                    result([NSNumber numberWithBool:isAutoTrackpage]);
  
                                   } else  if ([@"getBlackList" isEqualToString:call.method]) {
                                       NSArray * list = [[MLT_ConfigModel shareInstance] getBlackList];
                                       result(list);
                                          
                                          
                                  
                                          
                                      }   else {
    result(FlutterMethodNotImplemented);
  }
    } @catch (NSException *exception) {
        
    } @finally {
        
    }
}

@end

==> 0.3.5.tar.gz: ios/Classes/MzanalyticsMybmwPlugin.m <==
#import "MzanalyticsMybmwPlugin.h"
#import <MZAnalytics_MYBMW_1.0.3_SDK/MLTSiteSDK.h>
#import <MZAnalytics_MYBMW_1.0.3_SDK/MLT_ConfigModel.h>
@implementation MzanalyticsMybmwPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"mzanalytics_mybmw"
            binaryMessenger:[registrar messenger]];
  MzanalyticsMybmwPlugin* instance = [[MzanalyticsMybmwPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    @try {
        
   
   if ([@"appid" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
          
      [MLTSiteManager sharedInstanceWithAppId:call.arguments[@"appid"]  channel:@"app store"];
     
         
     }else if ([@"trackPageView" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
        
         [[MLTSiteManager  shareInstance] trackPageView:call.arguments[@"dt"]  appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else   if ([@"trackEvent" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
         
      [[MLTSiteManager  shareInstance] trackEvent:call.arguments[@"ec"] eventAction:call.arguments[@"ea"] eventTag:call.arguments[@"el"] eventPrice:call.arguments[@"ev"] appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else  if ([@"trackSiteCustomEvent" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         [[MLTSiteManager  shareInstance] trackSiteCustomEvent:call.arguments[@"CustomEvent"]  appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else  if ([@"trackPulse" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
         
      [[MLTSiteManager  shareInstance] trackPulse];
         
     } else  if ([@"getCid" isEqualToString:call.method]) {
        
            
         result([MLTSiteManager getCid]);
            
        } else  if ([@"setEnableLog" isEqualToString:call.method]) {
            result([NSNumber numberWithBool:YES]);

            [MLTSiteManager setEnableLog:[call.arguments[@"Enable"] boolValue]];
               
           }  else  if ([@"handleOpenURL" isEqualToString:call.method]) {
                  result([NSNumber numberWithBool:YES]);
                     
                     
                  [MLTSiteManager  handleOpenURL:call.arguments[@"url"]];
                     
                 }  else  if ([@"setCd" isEqualToString:call.method]) {
                     result([NSNumber numberWithBool:YES]);
                        
                        
                     [MLTSiteManager setCd:call.arguments[@"cd_key"] forValue:call.arguments[@"cd_value"]];
                        
                    }  else  if ([@"setCm" isEqualToString:call.method]) {
                        result([NSNumber numberWithBool:YES]);
                           
                           
                        [MLTSiteManager setCm:call.arguments[@"cm_key"] forValue:call.arguments[@"cm_value"]];
                           
                       }  else  if ([@"deleteCd" isEqualToString:call.method]) {
                           result([NSNumber numberWithBool:YES]);
                              
                              
                           [MLTSiteManager  deleteCdForKey:call.arguments[@"cd_key"]];
                              
                          }  else  if ([@"deleteCm" isEqualToString:call.method]) {
                              result([NSNumber numberWithBool:YES]);
                                 
                                 
                              [MLTSiteManager  deleteCmForKey:call.arguments[@"cm_key"]];
                                 
                             }  else  if ([@"getCdAndCm" isEqualToString:call.method]) {
                                 result([MLT_ConfigModel shareInstance].dmDict);
                                    
                                    
                             
                                    
                                } else  if ([@"isAutoTrackpage" isEqualToString:call.method]) {
                                
                                    BOOL isAutoTrackpage =[[MLT_ConfigModel shareInstance] isAutoTrackpage];
                                    result([NSNumber numberWithBool:isAutoTrackpage]);
  
                                   } else  if ([@"getManualtrackpage" isEqualToString:call.method]) {
                                 NSArray * list = [[MLT_ConfigModel shareInstance] getBlackList];
                                       result(list);
                                          
                                          
                                  
                                          
                                      }   else {
    result(FlutterMethodNotImplemented);
  }
    } @catch (NSException *exception) {
        
    } @finally {
        
    }
}

@end
